"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs-extra"));
const node_fetch_1 = tslib_1.__importDefault(require("node-fetch"));
const tough = require("tough-cookie");
const tough_cookie_filestore_1 = tslib_1.__importDefault(require("tough-cookie-filestore"));
const url = tslib_1.__importStar(require("url"));
const config_1 = tslib_1.__importDefault(require("./config"));
function encodeFormComponent(form) {
    return Object.entries(form).map(([key, value]) => `${encodeURIComponent(key)}=${encodeURIComponent(value)}`).join('&');
}
var ExportType;
(function (ExportType) {
    ExportType[ExportType["PDF"] = 0] = "PDF";
    ExportType[ExportType["SLIDE"] = 1] = "SLIDE";
    ExportType[ExportType["MD"] = 2] = "MD";
    ExportType[ExportType["HTML"] = 3] = "HTML";
})(ExportType = exports.ExportType || (exports.ExportType = {}));
/**
 * codimd API Client
 */
class API {
    constructor() {
        const { serverUrl, cookiePath } = config_1.default;
        fs.ensureFileSync(cookiePath);
        const jar = new tough_cookie_filestore_1.default(cookiePath);
        const fetch = require('fetch-cookie')(node_fetch_1.default, new tough.CookieJar(jar));
        this._fetch = fetch;
        this.serverUrl = serverUrl;
    }
    async login(email, password) {
        const response = await this.fetch(`${this.serverUrl}/login`, {
            method: 'post',
            body: encodeFormComponent({ email, password }),
            headers: {
                'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8'
            }
        });
        return response.status === 200;
    }
    async logout() {
        const response = await this.fetch(`${this.serverUrl}/logout`);
        return response.status === 200;
    }
    async isLogin() {
        const response = await this.fetch(`${this.serverUrl}/me`);
        return response.status === 200;
    }
    async getMe() {
        const response = await this.fetch(`${this.serverUrl}/me`);
        return response.json();
    }
    async getHistory() {
        const response = await this.fetch(`${this.serverUrl}/history`);
        return response.json();
    }
    async newNote(body) {
        const contentType = 'text/markdown;charset=UTF-8';
        const response = await this.fetch(`${this.serverUrl}/new`, {
            method: 'POST',
            body,
            headers: {
                'Content-Type': contentType
            }
        });
        if (response.status === 200) {
            return response.url;
        }
        else {
            throw new Error('Create note failed');
        }
    }
    async export(noteId, type, output) {
        let res;
        switch (type) {
            case ExportType.PDF:
                res = await this.fetch(`${this.serverUrl}/${noteId}/pdf`);
                break;
            case ExportType.HTML:
                res = await this.fetch(`${this.serverUrl}/s/${noteId}`);
                break;
            case ExportType.SLIDE:
                res = await this.fetch(`${this.serverUrl}/${noteId}/slide`);
                break;
            case ExportType.MD:
            default:
                res = await this.fetch(`${this.serverUrl}/${noteId}/download`);
        }
        return this.downloadFile(res, output);
    }
    async downloadFile(res, output) {
        const fileStream = fs.createWriteStream(output);
        await new Promise((resolve, reject) => {
            res.body.pipe(fileStream);
            res.body.on('error', (err) => {
                reject(err);
            });
            fileStream.on('finish', function () {
                resolve();
            });
        });
    }
    get fetch() {
        return this._fetch;
    }
    get domain() {
        return url.parse(this.serverUrl).host;
    }
}
exports.default = API;
exports.APIClient = new API();
