"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const inquirer = tslib_1.__importStar(require("inquirer"));
const api_1 = require("../api");
class Login extends command_1.Command {
    async run() {
        const { flags } = this.parse(Login);
        let email = flags.email;
        if (!email) {
            const out = await inquirer.prompt({
                type: 'input',
                name: 'email',
                message: 'Enter your email'
            });
            email = out.email;
            if (!email) {
                // TODO: do more email validation
                return this.log('No email is given');
            }
        }
        const { password } = await inquirer.prompt({
            type: 'password',
            name: 'password',
            message: 'Enter your password'
        });
        try {
            if (await api_1.APIClient.login(email, password)) {
                return this.log('Login successfully');
            }
            else {
                this.log('Login failed, please ensure your email/password is set');
            }
        }
        catch (err) {
            this.error(err);
        }
    }
}
exports.default = Login;
Login.description = 'Login HackMD instance from CLI';
Login.examples = [
    `$ codimd-cli login

Enter your email: hello@codimd.domain
Enter your password: *******

Login as HMD successfully!
`,
];
Login.flags = {
    help: command_1.flags.help({ char: 'h' }),
    email: command_1.flags.string({ char: 'u', description: 'Login email' })
};
