"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs-extra"));
const defaults_1 = tslib_1.__importDefault(require("lodash/defaults"));
const os_1 = require("os");
const path = tslib_1.__importStar(require("path"));
let configDir;
if (process.env.HMD_CLI_CONFIG_DIR) {
    configDir = process.env.HMD_CLI_CONFIG_DIR;
}
else {
    configDir = path.join(os_1.homedir(), '.codimd');
}
const configFilePath = path.join(configDir, 'config.json');
const defaultCookiePath = path.join(os_1.homedir(), '.codimd/cookies.json');
const defaultConfig = {
    cookiePath: defaultCookiePath
};
const envConfig = {
    cookiePath: process.env.CMD_CLI_COOKIE_PATH,
    serverUrl: process.env.CMD_CLI_SERVER_URL
};
const hasExistingConfig = fs.existsSync(configFilePath);
const readConfig = hasExistingConfig ? JSON.parse(fs.readFileSync(configFilePath, 'utf-8')) : {};
const defaultServerUrl = 'PLEASE FILL THE SERVER URL';
if (!hasExistingConfig) {
    fs.writeFileSync(configFilePath, JSON.stringify({ serverUrl: defaultServerUrl }, null, 2), 'utf-8');
}
const config = defaults_1.default(readConfig, envConfig, defaultConfig);
if (!config.serverUrl || config.serverUrl === defaultServerUrl) {
    throw new Error(`

Please specify CodiMD server url either in ${configFilePath} or by environment varaible.

You can learn how to config codimd-cli on https://github.com/hackmdio/codimd-cli

`);
}
exports.default = config;
